@@ -14,14 +14,12 @@
     :license: FreeBSD, see LICENSE file
 '''
 import argparse
-from datetime import datetime
-import jinja2
 import os
 import shutil
 import sphinx
-import subprocess
 import sys
-from tinkerer import draft, page, paths, post, utils, writer
+import locale
+from tinkerer import draft, page, paths, post, writer
 
 
 
@@ -49,14 +47,18 @@ def build(quiet=False, filename_only=False):
 
     flags = ["sphinx-build"]
     # silence Sphinx if in quiet mode
-    if quiet or filename_only: 
+    if quiet or filename_only:
         flags.append("-q")
     flags += ["-d", paths.doctree, "-b", "html", paths.root, paths.html]
 
     # build always prints "index.html"
     if filename_only:
         print("index.html")
-    
+
+    # copy some extra files to the output directory
+    if os.path.exists("_copy"):
+        shutil.copytree("_copy/", paths.html)
+        
     return sphinx.main(flags)
 
 
@@ -81,7 +83,7 @@ def create_post(title, quiet=False, filename_only=False):
             print("New post created as '%s'" % new_post.path)
 
 
- 
+
 def create_page(title, quiet=False, filename_only=False):
     '''
     Creates a new page with the given title or makes an existing file a page.
@@ -128,14 +130,15 @@ def main(argv=None):
     '''
     Parses command line and executes required action.
     '''
+    locale.setlocale(locale.LC_ALL, '')
     parser = argparse.ArgumentParser()
     group = parser.add_mutually_exclusive_group()
     group.add_argument("-s", "--setup", action="store_true", help="setup a new blog")
     group.add_argument("-b", "--build", action="store_true", help="build blog")
-    group.add_argument("-p", "--post", nargs=1, 
+    group.add_argument("-p", "--post", nargs=1,
             help="create a new post with the title POST (if a file named POST "
                  "exists, it is moved to a new post instead)")
-    group.add_argument("--page", nargs=1, 
+    group.add_argument("--page", nargs=1,
             help="create a new page with the title PAGE (if a file named PAGE "
                  "exists, it is moved to a new page instead)")
     group.add_argument("-d", "--draft", nargs=1,
@@ -144,18 +147,22 @@ def main(argv=None):
 
     group = parser.add_mutually_exclusive_group()
     group.add_argument("-q", "--quiet", action="store_true", help="quiet mode")
-    group.add_argument("-f", "--filename", action="store_true", 
-            help="output filename only - useful to pipe Tinkerer commands") 
+    group.add_argument("-f", "--filename", action="store_true",
+            help="output filename only - useful to pipe Tinkerer commands")
 
     command = parser.parse_args(argv)
 
     # tinkerer should be run from the blog root unless in setup mode
-    if not command.setup and not os.path.exists(
-                os.path.join(paths.root, "./conf.py")):
+    if not command.setup and not os.path.exists(paths.conf_file):
         sys.stderr.write("Tinkerer must be run from your blog root "
                 "(directory containing 'conf.py')\n")
         return -1
-    
+    # in setup mode it should fail if run from a blog root
+    elif command.setup and os.path.exists(paths.conf_file):
+        sys.stderr.write("'conf.py' already exists in current directory, "
+                "choose a different directory to setup your blog.\n")
+        return -1
+
 
     if command.setup:
         setup(command.quiet, command.filename)
